package com.jeesharp.business.modules.finance.profitsharing.service;

import com.jeesharp.business.modules.finance.profitsharing.entity.ProfitSharingReturn;
import com.jeesharp.business.modules.finance.profitsharing.vo.ProfitSharingReturnQueryVO;
import com.jeesharp.framework.mybatis.core.service.BaseInterface;

/**
 * 分账回退单领域服务接口。
 *
 * @author jeesharp
 * @since 2026-06-11
 */
public interface ProfitSharingReturnService extends BaseInterface<ProfitSharingReturn, ProfitSharingReturnQueryVO> {

    ProfitSharingReturn findByPayRefundOrderId(String payRefundOrderId);

    int sumSuccessReturnFenByProfitSharingOrderId(String profitSharingOrderId);

    ProfitSharingReturn createReturnOrder(ProfitSharingReturn entity);

    void updateReturnOrder(ProfitSharingReturn entity);
}
